| Title: | Very Fast PNG Image Reader/Writer for 24/32bpp Images |
|---|---|
| Description: | Wraps 'fpng', a very fast C++ .PNG image reader/writer for 24/32bpp images |
| Authors: | David Schoch [aut, cre] (ORCID: <https://orcid.org/0000-0003-2952-4812>) |
| Maintainer: | David Schoch <[email protected]> |
| License: | `use_mit_license()`, `use_gpl3_license()` or friends to pick a license |
| Version: | 0.0.0.9000 |
| Built: | 2026-05-27 06:11:00 UTC |
| Source: | https://github.com/schochastics/RFPNG |
Initialize fpng run one time on startup
fpng_init()fpng_init()
convert png to be compatible with fpng
png2fpng(png_path, fpng_path)png2fpng(png_path, fpng_path)
png_path |
path to png file to be converted |
fpng_path |
path to output png file |
Decode from file Reads an image from a PNG file into a raster array.
readFPNG(file_path)readFPNG(file_path)
file_path |
character. file to write to |
array representing the FPNG image
Reshape png array Reshape a png array that was read with png::readPNG to comply with fpng
reshape_to_fpng(x)reshape_to_fpng(x)
x |
array representing a png image |
Encode to file Create a FPNG image from an array or matrix.
writeFPNG(x, file_path)writeFPNG(x, file_path)
x |
image represented by an integer matrix with values between 0 and 255. Either three (RGB) or four (RGB+alpha) planes. |
file_path |
character. file to write to |
bool